# burn: Burn Until Recorded, Now!

## Installation

In order to use burn properly, please follow the following steps.

# Dependencies

Be sure you have installed properly:

- python (>= 2.5)
- wodim
- genisoimage
- cdrdao
- eyeD3 <http://www.travisshirk.net/eyeD3/releases> (generic MP3 tag modules for Python)
- pyogg (python-pyvorbis) <http://www.andrewchatham.com/pyogg/> (generic Ogg Vorbis modules for Python)

Please refer to the documentation provided with the above programs in order to make them work.

Optionally you can choose not to decode mp3 and ogg files with native burn functions choosing to do it with external decoders. If you want to do so, you have to install preferred decoders (lame, ogg123, mpg321, mpg123, etc.) and set up burn.conf.

Warning powerpc users: internal decoder (mp3 to wav) does not work. Please use external decoding.

## Development dependencies

For development work on Burn, you will need the following additional packages installed (each one available from the Debian package named in parentheses):

- setuptools (`python-setuptools`)
- nose (`python-nose`)
- MiniMock (`python-minimock`) version 1.2.2 or later
- Docutils (`python-docutils`) version 0.5 or later
- Docutils manpage writer (`docutils-writer-manpage`)
- Lynx (`lynx`)

The distribution build program is `setup.py` in the source tree. Use this program to build, test, install, or any other actions permitted with distutils or setuptools.

# Package installation

It is possible to unpack the source tarball and run the programs directly from the source directory. This limits you to only running the programs from a specific directory, though.

If you want the programs available from anywhere on the system, you should install the package using Python's standard distutils installation method:

    $ python ./setup.py install

This will install executable programs and Python libraries to the default locations. Refer to the distutils user documentation for customisation of install location and other options.

# Configuration file location

(You can skip this step if you want to use burn from newly uncompressed directory. For example with point and slash in front of it: ./burn)

- move configuration file (burn.conf) to your preferred location (e.g.: /etc/)
- edit burn executable
- find the line below the comment line: # CONFIGURATION FILE LOCATION *************************
- set the absolute path for burn.conf file. e.g.: config.read(['/etc/burn.conf/'])

# Configure values

Edit configuration file (burn.conf) in order to change values to set your preferences.

- In section [executables] please add full path to binaries.

    Here you can also enable external mp3 and ogg decoders.

- In section [ISO] you'll have to specify: temporary image directory name, temporary image name, Joliet support, mount point

- In section [CD-writer] you should configure your cd-writer device. Remember you can get LUN values for your (emulated or not) SCSI units with the following cdrecord command:

  > > # wodim -scanbus

  > You can also choose to enable Buffer Underrun Free writing on with burnfree option.

- In section [CD-reader] you have to configure your CD reader unit. If you only have a cd-writer unit, use the same cd-writer LUN

- In section [Media] you can configure media's capacity.

Ok, that's it. Now burn should be properly set up. try to launch it without any options. You should get help.

Remember: you have to have root privileges in order to use burn.